@@ -2,7 +2,7 @@
 
 require(rJava, quietly=TRUE)
 
-.First.lib <- function(lib, pkg) {
+.onLoad <- function(lib, pkg) {
     dlp<-Sys.getenv("DYLD_LIBRARY_PATH")
     if (dlp!="") { # for Mac OS X we need to remove X11 from lib-path
         Sys.setenv("DYLD_LIBRARY_PATH"=sub("/usr/X11R6/lib","",dlp))
